{% extends "base.jinja2" %}

{% block header -%}
<html>
<!-- This page has been autogenerated using Frigate. https://frigate.readthedocs.io -->
<head>
  <title>{{ name | capitalize }}</title>
</head>
<body>
{% endblock %}

{% block title -%}
<h1>
  {{ name | capitalize }}
</h1>
{% endblock -%}

{% block description -%}
<p>
  {{ description }}
</p>

<p>
  {{ long_description }}
</p>
{% endblock -%}

{% block table -%}
<h2>
  Configuration
</h2>

<p>
  The following table lists the configurable parameters of the {{ name | capitalize }} chart and their default values.
</p>

<table style="width:100%">
  <tr>
    <th>Parameter</th>
    <th>Description</th>
    <th>Default</th>
  </tr>
  {% for (param, comment, default) in values -%}
  <tr>
    <td><code>{{ param }}</code></td>
    <td>{{ comment }}</td>
    <td><code>{{ default }}</code></td>
  </tr>
  {% endfor -%}
</table>
{% endblock -%}

{% block footnotes -%}
<p>
  {{ footnotes }}
</p>
{% endblock -%}

{% block credits -%}
{%- if credits -%}
<hr />
<p><i>Documentation generated by <a href="https://frigate.readthedocs.io">Frigate</a>.</i></p>
{%- endif -%}
{%- endblock %}

{% block footer -%}
</body>
</html>
{% endblock %}