{% extends "base.jinja2" %}

{% block title -%}
{{ name | capitalize }}
===========
{% endblock %}

{% block description -%}
{{ description }}

{{ long_description }}
{%- endblock %}

{% block table -%}
## Configuration

The following table lists the configurable parameters of the {{ name | capitalize }} chart and their default values.

| Parameter                | Description             | Default        |
| ------------------------ | ----------------------- | -------------- |
{% for (param, comment, default) in values -%}
| `{{ param }}` | {{ comment }} | `{{ default }}` |
{% endfor -%}
{%- endblock %}

{% block footnotes -%}
{{ footnotes }}
{% endblock -%}

{% block credits -%}
{%- if credits -%}
---
_Documentation generated by [Frigate](https://frigate.readthedocs.io)._
{%- endif -%}
{%- endblock %}