{% block header %}{% endblock %}
{% block title %}{% endblock %}
{% block description %}{% endblock %}
{% block table %}{% endblock %}
{% block footnotes %}{% endblock %}
{% block credits %}{% endblock %}
{% block footer %}{% endblock %}